<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=en
// ** ne pas modifier le fichier **

return [

	// A
	'activer_plugin' => 'Enable plugin',
	'affichage' => 'Display',
	'aide_non_disponible' => 'This part of the online help is not yet available in this language.',
	'annuler_recherche' => 'Cancel the search',
	'auteur' => 'Author:',
	'avis_acces_interdit' => 'Access forbidden.',
	'avis_acces_interdit_prive' => 'You are not allowed to access the page <b>@exec@</b>.',
	'avis_article_modifie' => 'Warning: @nom_auteur_modif@ modified this article @date_diff@ minutes ago',
	'avis_aucun_resultat' => 'No results found.',
	'avis_base_inaccessible' => 'Impossible to connect to the database @base@.',
	'avis_chemin_invalide_1' => 'The path you selected',
	'avis_chemin_invalide_2' => 'does not seem to be valid. Please go back to previous page and check the information you provided.',
	'avis_connexion_echec_1' => 'Connection to the SQL server failed.',
	'avis_connexion_echec_2' => 'Go back to the previous page, and check the information you provided.',
	'avis_connexion_echec_3' => '<b>N.B.</b> On many servers, you must <b>request</b> activation of your access to the SQL database before you can use it. If you cannot connect to your database, check that activation has been done.',
	'avis_connexion_erreur_creer_base' => 'The database could not be created.',
	'avis_connexion_erreur_fichier_cle_manquant_1' => 'Installation must be performed by a web-master or a web-mistress with a backup of the keys and their password',
	'avis_connexion_erreur_fichier_cle_manquant_2' => 'Installation must be performed by a web-master or a web-mistress with a backup of the keys',
	'avis_connexion_erreur_nom_base' => 'The database’s name should only contain letters, digits and hyphens.',
	'avis_connexion_ldap_echec_1' => 'Connection to the LDAP server failed.',
	'avis_connexion_ldap_echec_2' => 'Go back to the previous page, and check the information you provided.',
	'avis_connexion_ldap_echec_3' => 'Alternatively, do not use LDAP support to import accounts.',
	'avis_deplacement_rubrique' => 'Warning! This section contains @contient_breves@ news item@scb@: if you move it, please check this box to confirm.',
	'avis_erreur_connexion_mysql' => 'SQL connection error',
	'avis_erreur_creation_compte' => 'Failure during account initialisation',
	'avis_espace_interdit' => '<b>Forbidden area</b> <div>SPIP is already installed.</div>',
	'avis_lecture_noms_bases_1' => 'The installer could not read the names of any databases already installed.',
	'avis_lecture_noms_bases_2' => 'Either no database is available, or the option listing databases was disabled for security reasons (which is the case with various hosting services).',
	'avis_lecture_noms_bases_3' => 'In the second case, a database named after your login might already be available:',
	'avis_non_acces_page' => 'You do not have access to this page.',
	'avis_operation_echec' => 'The operation failed.',
	'avis_operation_impossible' => 'Operation impossible',
	'avis_suppression_base' => 'WARNING: data deletion is irreversible',

	// B
	'bouton_acces_ldap' => 'Add LDAP access',
	'bouton_ajouter' => 'Add',
	'bouton_annuler' => 'Cancel',
	'bouton_cache_activer' => 'Re-activate the cache',
	'bouton_cache_desactiver' => 'Disable the cache momentarily',
	'bouton_demande_publication' => 'Request publication of this article',
	'bouton_desactive_tout' => 'Disable all',
	'bouton_desinstaller' => 'Uninstall',
	'bouton_effacer_tout' => 'Delete ALL',
	'bouton_envoyer_message' => 'Message complete: send',
	'bouton_fermer' => 'Close',
	'bouton_mettre_a_jour' => 'Update',
	'bouton_mettre_a_jour_base' => 'Update the database',
	'bouton_modifier' => 'Modify',
	'bouton_radio_afficher' => 'Show',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Appear in the list of persons on-line',
	'bouton_radio_envoi_annonces_adresse' => 'Send announcements to:',
	'bouton_radio_envoi_liste_nouveautes' => 'Send news update list',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Do not appear in the list of persons on-line',
	'bouton_radio_non_envoi_annonces_editoriales' => 'Do not send any editorial announcements',
	'bouton_redirection' => 'REDIRECT',
	'bouton_reinitialiser_aux_valeurs_par_defaut' => 'Reset to default values',
	'bouton_relancer_inscription' => 'Re-launch registration',
	'bouton_relancer_inscriptions' => 'Re-launch registrations',
	'bouton_relancer_installation' => 'Recommence installation',
	'bouton_reset_password' => 'Create a new password and send by e-mail',
	'bouton_suivant' => 'Next',
	'bouton_tenter_recuperation' => 'Attempt to repair',
	'bouton_test_proxy' => 'Test the proxy',
	'bouton_vider_cache' => 'Empty the cache',

	// C
	'cache_modifiable_webmestre' => 'This parameter can be modified by the web-master or the web-mistress.',
	'calendrier_synchro' => 'If you use a calendar application compatible with <b>iCal</b>, you can synchronise it with information from this site.',
	'config_activer_champs' => 'Activate the following fields',
	'config_choix_base_sup' => 'Choose a database on this server',
	'config_erreur_base_sup' => 'SPIP does not have access to the list of databases available',
	'config_info_base_sup' => 'If you need to query other databases using SPIP, whether on this SQL server or elsewhere, use this form to declare them. If you leave any fields empty, connection details to the main database will be used.',
	'config_info_base_sup_disponibles' => 'Additional databases to which queries may be sent:',
	'config_info_enregistree' => 'The new configuration has been saved',
	'config_info_logos' => 'Each element of the site can have its own logo as well as a "mouseover" logo',
	'config_info_logos_utiliser' => 'Use logos',
	'config_info_logos_utiliser_non' => 'Do not use logos',
	'config_info_logos_utiliser_survol' => 'Use "mouseover" logos',
	'config_info_logos_utiliser_survol_non' => 'Do not use "mouseover" logos',
	'config_info_redirection' => 'By activating this option you can create virtual articles, which are simply links to articles published on other sites, not necessarily using SPIP.',
	'config_redirection' => 'Virtual articles',
	'config_titre_base_sup' => 'Declaration of an additional database',
	'config_titre_base_sup_choix' => 'Choose an additional database',
	'connexion_ldap' => 'Connection:',
	'creer_et_associer_un_auteur' => 'Create and associate an author',

	// D
	'date_mot_heures' => 'H',

	// E
	'ecran_connexion_couleur_principale' => 'Main colour',
	'ecran_connexion_image_fond' => 'Background image',
	'ecran_connexion_image_fond_explication' => 'Use an image (JPEG format, 1920x1080 pixels)',
	'ecran_connexion_image_revenir_couleur_defaut' => 'Back to the default colour',
	'ecran_connexion_titre' => 'Connection screen',
	'ecran_securite' => '+ safety screen @version@',
	'email' => 'email',
	'email_2' => 'email:',
	'en_savoir_plus' => 'Learn more',
	'entree_adresse_annuaire' => 'Directory address',
	'entree_adresse_email' => 'Your email address',
	'entree_adresse_email_2' => 'E-mail address',
	'entree_base_donnee_1' => 'Database address',
	'entree_base_donnee_2' => '(This address is often your site’s URL, although sometimes it will be "localhost", and sometimes it should be left blank.)',
	'entree_biographie' => 'Brief biography',
	'entree_chemin_acces' => '<b>Enter</b> the path:',
	'entree_cle_pgp' => 'Your PGP key',
	'entree_cle_pgp_2' => 'PGP key',
	'entree_contenu_rubrique' => '(Brief description of the content of this section.)',
	'entree_identifiants_connexion' => 'Your connection identifiers...',
	'entree_identifiants_connexion_2' => 'Connection identifiers',
	'entree_informations_connexion_ldap' => 'Please fill this form with the LDAP connection information.
	These informations should be provided by your system or network admin.',
	'entree_infos_perso' => 'Who are you?',
	'entree_infos_perso_2' => 'Who is the author?',
	'entree_interieur_rubrique' => 'In the section:',
	'entree_liens_sites' => '<b>Hyperlink</b> (reference, site to visit etc.)',
	'entree_login' => 'Your login',
	'entree_login_connexion_1' => 'Connection login',
	'entree_login_connexion_2' => '(Sometimes matches your FTP account login and sometimes left empty)',
	'entree_mot_passe' => 'Your password',
	'entree_mot_passe_1' => 'Password',
	'entree_mot_passe_2' => '(Sometimes matches your FTP access password and sometimes left empty)',
	'entree_nom_fichier' => 'Please enter the filename @texte_compresse@:',
	'entree_nom_pseudo' => 'Your name or alias',
	'entree_nom_pseudo_1' => '(Your name or alias)',
	'entree_nom_pseudo_2' => 'Name or alias',
	'entree_nom_site' => 'Website’s name',
	'entree_nom_site_2' => 'Author’s website’s name',
	'entree_nouveau_passe' => 'New password',
	'entree_passe_ldap' => 'Password',
	'entree_port_annuaire' => 'Port number of the directory',
	'entree_signature' => 'Signature',
	'entree_titre_obligatoire' => '<b>Title</b> [Required]<br />',
	'entree_url' => 'Website’s URL',
	'entree_url_2' => 'Website’s URL',
	'erreur_connect_deja_existant' => 'A server by that name already exists',
	'erreur_contenu_suspect' => 'Text escaped',
	'erreur_email_deja_existant' => 'This email address has already been registered.',
	'erreur_nom_connect_incorrect' => 'Server name not allowed',
	'erreur_plugin_attribut_balise_manquant' => 'Missing attribute @attribut@ in tag @balise@',
	'erreur_plugin_desinstalation_echouee' => 'Uninstallation of the plugin failed. However, you may deactivate it.',
	'erreur_plugin_fichier_absent' => 'File missing',
	'erreur_plugin_fichier_def_absent' => 'Definition file missing',
	'erreur_plugin_nom_fonction_interdit' => 'Prohibited function name',
	'erreur_plugin_nom_manquant' => 'Missing plugin name',
	'erreur_plugin_prefix_manquant' => 'Namespace undefined for this plugin',
	'erreur_plugin_tag_plugin_absent' => '&lt;plugin&gt; missing in the definition file',
	'erreur_plugin_version_manquant' => 'Plugin version missing',
	'erreur_type_fichier' => 'Wrong file type',

	// H
	'htaccess_a_simuler' => 'Warning: your HTTP server configuration ignores @htaccess@ files. To ensure good security, you should change the configuration for this. Alternatively, you should make sure that the constants @constantes@ (definable in the file mes_options.php) have as values directories outside @document_root@.',
	'htaccess_inoperant' => 'inoperative htaccess',

	// I
	'ical_info1' => 'This page offers several tools to be kept  up-to-date with website’s activity.',
	'ical_info2' => 'For more information, do not hesitate to visit <a href="@spipnet@">SPIP’s documentation</a>.',
	'ical_info_calendrier' => 'Two calendars are available. The first is a general, public calendar showing  articles as they are published. The second is personal and contains editorial announcements as well as your latest private messages: it is reserved for you via a personal key that you can modify at any time by renewing your password.',
	'ical_methode_http' => 'Downloading',
	'ical_methode_webcal' => 'Synchronisation (webcal://)',
	'ical_texte_prive' => 'This calendar, which is strictly personal, informs you of the private editorial activity of this site (tasks, personal appointments, articles and news items submitted etc.).',
	'ical_texte_public' => 'This calendar allows you to follow the public activity of this site (newly-published articles and news items).',
	'ical_texte_rss' => 'You can syndicate the latest news from this site in any XML/RSS (Rich Site Summary) reader. This is also the format that allows SPIP to read the latest news published by other sites using a compatible exchange format (syndicated sites).',
	'ical_titre_js' => 'Javascript',
	'ical_titre_mailing' => 'Mailing-list',
	'ical_titre_rss' => 'Syndication files',
	'icone_accueil' => 'Home',
	'icone_activer_cookie' => 'Place a cookie',
	'icone_activite' => 'Feedback',
	'icone_admin_plugin' => 'Manage plugins',
	'icone_administration' => 'Maintenance',
	'icone_afficher_auteurs' => 'Show authors',
	'icone_afficher_visiteurs' => 'Show visitors',
	'icone_arret_discussion' => 'Stop participating in this discussion',
	'icone_calendrier' => 'Calendar',
	'icone_configuration' => 'Configuration',
	'icone_creer_auteur' => 'Create a new author and link him/her to this article',
	'icone_creer_mot_cle' => 'Create a new keyword and link it to this article',
	'icone_creer_rubrique_2' => 'Create a new section',
	'icone_developpement' => 'Development',
	'icone_edition' => 'Edit',
	'icone_ma_langue' => 'My language',
	'icone_mes_infos' => 'My details',
	'icone_mes_preferences' => 'Preferences',
	'icone_modifier_article' => 'Edit this article',
	'icone_modifier_rubrique' => 'Edit this section',
	'icone_outils_rapides' => 'Create',
	'icone_publication' => 'Publish',
	'icone_relancer_signataire' => 'Contact the signatory again',
	'icone_retour' => 'Back',
	'icone_retour_article' => 'Back to the article',
	'icone_squelette' => 'Templates',
	'icone_suivi_publication' => 'Publication follow up ',
	'icone_supprimer_cookie' => 'Delete cookie',
	'icone_supprimer_rubrique' => 'Delete this section',
	'icone_supprimer_signature' => 'Delete this signature',
	'icone_valider_signature' => 'Validate this signature',
	'image_administrer_rubrique' => 'You can manage this section',
	'impossible_modifier_login_auteur' => 'Login cannot be changed.',
	'impossible_modifier_pass_auteur' => 'Password cannot be changed.',
	'info_1_article' => '1 article',
	'info_1_auteur' => '1 author',
	'info_1_message' => '1 message',
	'info_1_mot_cle' => '1 keyword',
	'info_1_rubrique' => '1 section',
	'info_1_visiteur' => '1 visitor',
	'info_activer_cookie' => 'You can activate an <b>administration cookie</b>, which lets you switch easily between the public website and the admin area.',
	'info_activer_menu_developpement' => 'Show the Development menu',
	'info_admin_etre_webmestre' => 'Give me web administrator rights',
	'info_admin_je_suis_webmestre' => 'I am a <b>webmaster</b>',
	'info_admin_statuer_webmestre' => 'Give web-master (web-mistress) rights to this admin',
	'info_admin_webmestre' => 'This admin is <b>webmaster</b>',
	'info_administrateur' => 'Admin',
	'info_administrateur_1' => 'Admin',
	'info_administrateur_2' => 'of the site (<i>use with caution</i>)',
	'info_administrateur_site_01' => 'If you are a site admin, please',
	'info_administrateur_site_02' => 'click on this link',
	'info_administrateurs' => 'Admin',
	'info_administrer_rubrique' => 'You can manage this section',
	'info_adresse' => 'to this address:',
	'info_adresse_desinscription' => 'Unsubscription address:',
	'info_adresse_inscription' => 'Registration address:',
	'info_adresse_url' => 'URL of the public site',
	'info_afficher_par_nb' => 'Show ',
	'info_aide_en_ligne' => 'SPIP Online Help',
	'info_ajout_image' => 'When you add images as attached documents to an article,
  SPIP can automatically create thumbnails from
  inserted images. This will allow, for instance, the automated
  creation of a gallery or portfolio.',
	'info_ajouter_rubrique' => 'Add another section to manage:',
	'info_annonce_nouveautes' => 'Latest news announcements',
	'info_article' => 'article',
	'info_article_2' => 'articles',
	'info_article_a_paraitre' => 'Post-dated articles set for publication',
	'info_articles_02' => 'articles',
	'info_articles_2' => 'Articles',
	'info_articles_auteur' => 'Articles by this author',
	'info_articles_miens' => 'My articles',
	'info_articles_tous' => 'All the articles',
	'info_articles_trouves' => 'Articles found',
	'info_attente_validation' => 'Your articles awaiting validation',
	'info_aucun_article' => 'No articles',
	'info_aucun_auteur' => 'No authors',
	'info_aucun_message' => 'No messages',
	'info_aucun_rubrique' => 'No sections',
	'info_aujourdhui' => 'today:',
	'info_auteur_gere_rubriques' => 'This author manages the following sections:',
	'info_auteur_gere_toutes_rubriques' => 'This author manage <b>all the sections</b>',
	'info_auteur_gere_toutes_rubriques_2' => 'I manage <b>all the sections</b>',
	'info_auteurs' => 'Authors',
	'info_auteurs_par_tri' => 'Authors@partri@',
	'info_auteurs_trouves' => 'Authors found',
	'info_authentification_externe' => 'External authentication',
	'info_avertissement' => 'Warning',
	'info_barre_outils' => 'with its toolbar?',
	'info_base_installee' => 'Your database structure has been installed.',
	'info_bio' => 'Biography',
	'info_cache_desactive' => 'The cache is temporarily disabled',
	'info_chapeau' => 'Introduction',
	'info_chapeau_2' => 'Introduction:',
	'info_chemin_acces_1' => 'Options: <b>Access path in directory</b>',
	'info_chemin_acces_2' => 'You must now configure the access path to the directory information. This information is essential to read the data stored in the directory.',
	'info_chemin_acces_annuaire' => 'Options: <b>Access path in directory</b>',
	'info_choix_base' => 'Third step:',
	'info_classement_1' => ' out of @liste@',
	'info_classement_2' => ' out of @liste@',
	'info_code_acces' => 'Do not forget your own access codes!',
	'info_config_suivi' => 'If this address corresponds to a mailing list, you can indicate the subscription address for this list. This may be a URL (e.g. a webpage enabling subscription online), or an email address with a specific subject (for instance: <tt>@adresse_suivi@?subject=subscribe</tt>):',
	'info_config_suivi_explication' => 'You can subscribe to the mailing-list for this site. You will then receive email announcements concerning articles and news items submitted for publication.',
	'info_confirmer_passe' => 'Confirm new password:',
	'info_conflit_edition_avis_non_sauvegarde' => 'Caution: the following fields have been modified elsewhere. Your changes to these fields have therefore not been saved.',
	'info_conflit_edition_differences' => 'Differences:',
	'info_conflit_edition_version_enregistree' => 'Saved version:',
	'info_conflit_edition_votre_version' => 'Your version:',
	'info_connexion_base' => 'Trying to connect to database',
	'info_connexion_base_donnee' => 'Connection to your database',
	'info_connexion_ldap_ok' => '<b>LDAP connection succeeded.</b><p> You can go to the next step.</p>',
	'info_connexion_mysql' => 'Your SQL connection',
	'info_connexion_ok' => 'Connection succeeded.',
	'info_contact' => 'Contact',
	'info_contenu_articles' => 'Article content',
	'info_contributions' => 'Contributions',
	'info_creation_paragraphe' => 'To create paragraphs, just leave blank lines.',
	'info_creation_rubrique' => 'Before writing any articles,<br /> you must create at least one section.<br />',
	'info_creation_tables' => 'Creating the database tables',
	'info_creer_base' => '<b>Create</b> a new database:',
	'info_dans_rubrique' => 'In section:',
	'info_date_publication_anterieure' => 'Previously published on:',
	'info_date_referencement' => 'THIS SITE REFERENCED ON:',
	'info_derniere_etape' => 'Done!',
	'info_descriptif' => 'Description:',
	'info_desinstaller_plugin' => ' deactivates the plugin and deletes the data',
	'info_discussion_cours' => 'Current discussions',
	'info_ecrire_article' => 'Before writing any articles, you must create at least one section.',
	'info_email_envoi' => 'Sender’s email address (optional)',
	'info_email_envoi_txt' => 'Enter the sender’s email address used for sending emails (by default, the recipient’s address is used as the sender’s address) :',
	'info_email_webmestre' => 'Web-master’s or web-mistress email address',
	'info_envoi_email_automatique' => 'Automated mailing',
	'info_envoyer_maintenant' => 'Send now',
	'info_erreur_version_base_plus_recente' => 'Installation error',
	'info_etape_suivante' => 'Go to the next step',
	'info_etape_suivante_1' => 'You can move on to the next step.',
	'info_etape_suivante_2' => 'You can move on to the next step.',
	'info_exceptions_proxy' => 'Exceptions for the proxy',
	'info_exportation_base' => 'export database to @archive@',
	'info_facilite_suivi_activite' => 'To simplify monitoring of the site’s editorial
  activities, SPIP can send by e-mail, e.g. to a mailing list,
  notifications of publication requests and articles validations. Enter one or more addresses separated by commas.',
	'info_fichiers_authent' => 'Authentication file ".htpasswd"',
	'info_forums_abo_invites' => 'Your site contains forums by subscription; visitors may register for them on the public site.',
	'info_gauche_admin_bdd' => '<b>This page is available to the persons responsible of the site only.</b><p> It gives access to the various database features. Some of them require a specific authentication process which 
involves an FTP access to the site.</p>',
	'info_gauche_admin_tech' => '<b>Only webmasters have access to this page.</b><p> It provides access to various
maintenance tasks. Some of them require a specific authentication process
via FTP.</p>',
	'info_gauche_auteurs' => 'All the site authors are listed here.
 The status of each is indicated by the colour of their icon (admin = green; editor = yellow).',
	'info_gauche_auteurs_exterieurs' => 'Visiting authors, without any access to the site, are indicated by a blue icon; deleted authors by a grey icon.',
	'info_gauche_messagerie' => 'Internal messaging lets you exchange messages between accounts, keep memos (for personal use) or, display announcements on the back office homepage (if you are an admin).',
	'info_gauche_statistiques_referers' => 'This page displays the list of <i>referrers</i>, i.e. websites containing links to your own site, for yesterday and today. The list is reset every 24 hours.',
	'info_gauche_visiteurs_enregistres' => 'You will find here the visitors registered
 for the public area of the site (subscription-only forums).',
	'info_generation_miniatures_images' => 'Generation of thumbnail images',
	'info_gerer_trad_objets' => '@objets@: manage translation links',
	'info_hebergeur_desactiver_envoi_email' => 'Some hosts disable automated mail sending
		on their servers. In this case the following features
		of SPIP cannot be implemented.',
	'info_hier' => 'yesterday:',
	'info_identification_publique' => 'Your public identity...',
	'info_image_process' => 'Select the best method to create thumbnails by clicking on the corresponding picture.',
	'info_image_process2' => 'If you can’t see any images, then your server is not configured to use such tools. If you want to use these features, contact your provider’s technical support and ask for the «GD» or «Imagick» extensions to be installed.',
	'info_images_auto' => 'Images calculated automatically',
	'info_informations_personnelles' => 'Personal information',
	'info_inscription' => 'Registered on',
	'info_inscription_automatique' => 'Automatic registration of new accounts',
	'info_jeu_caractere' => 'Character set for the site',
	'info_jours' => 'days',
	'info_laisser_champs_vides' => 'leave these fields empty)',
	'info_langues' => 'Site languages',
	'info_ldap_ok' => 'LDAP authentication is installed.',
	'info_lien_hypertexte' => 'Hyperlink:',
	'info_liste_nouveautes_envoyee' => 'The news update list has been sent',
	'info_liste_redacteurs_connectes' => 'List of persons on-line',
	'info_login_existant' => 'This login already exists.',
	'info_login_trop_court' => 'Login too short.',
	'info_login_trop_court_car_pluriel' => 'Your login must contain at least @nb@ characters.',
	'info_logos' => 'Logos',
	'info_maximum' => 'maximum:',
	'info_meme_rubrique' => 'In this section',
	'info_message_en_redaction' => 'Your draft messages',
	'info_message_technique' => 'Technical message:',
	'info_messagerie_interne' => 'Internal messaging',
	'info_mise_a_niveau_base' => 'SQL database upgrade',
	'info_mise_a_niveau_base_2' => '{{Warning!}} You have installed an {older} SPIP version, prior to the one
  originally installed on this website: your database is at risk of being corrupted
  and your site might not work properly anymore.<br />{{Please, re-install
  SPIP files.}}',
	'info_modification_enregistree' => 'Your changes have been saved',
	'info_modifier_auteur' => 'Edit author details:',
	'info_modifier_rubrique' => 'Edit the section:',
	'info_modifier_statut' => 'Change status',
	'info_modifier_titre' => 'Edit: @titre@',
	'info_mon_site_spip' => 'My SPIP site',
	'info_moyenne' => 'average:',
	'info_multi_cet_article' => 'Language for this article:',
	'info_multi_langues_choisies' => 'Please select the languages to be made available for editing.
  Languages already used on your site (at the top of the list) cannot be disabled.',
	'info_multi_objets' => '@objets@: activate the language menu',
	'info_multi_secteurs' => '... only for root-level sections?',
	'info_nb_articles' => '@nb@ articles',
	'info_nb_auteurs' => '@nb@ authors',
	'info_nb_messages' => '@nb@ messages',
	'info_nb_mots_cles' => '@nb@ keywords',
	'info_nb_rubriques' => '@nb@ sections',
	'info_nb_visiteurs' => '@nb@ visitors',
	'info_nom' => 'Name',
	'info_nom_destinataire' => 'Name of recipient',
	'info_nom_pas_conforme' => 'html tags are not allowed',
	'info_nom_site' => 'Name of your site',
	'info_nombre_articles' => '@nb_articles@ articles,',
	'info_nombre_rubriques' => '@nb_rubriques@ sections,',
	'info_nombre_sites' => '@nb_sites@ sites,',
	'info_non_deplacer' => 'Do not move...',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP can send a site newsletter (list of newly-published articles and news items).
  .',
	'info_non_envoi_liste_nouveautes' => 'Do not send newsletter',
	'info_non_modifiable' => 'cannot be modified',
	'info_non_suppression_mot_cle' => 'I do not want to delete this keyword.',
	'info_notes' => 'Footnotes',
	'info_nouvel_article' => 'New article',
	'info_nouvelle_traduction' => 'New translation:',
	'info_numero_article' => 'ARTICLE NUMBER:',
	'info_obligatoire_02' => '(Required)',
	'info_option_accepter_visiteurs' => 'Allow the creation of visitors accounts via the public site',
	'info_option_ne_pas_accepter_visiteurs' => 'Disable visitors’ accounts creation',
	'info_options_avancees' => 'ADVANCED OPTIONS',
	'info_ou' => 'or...',
	'info_page_interdite' => 'Forbidden page',
	'info_par_nom' => 'by name',
	'info_par_nombre_article' => 'by number of articles',
	'info_par_statut' => 'by status',
	'info_par_tri' => '’(by @tri@)’',
	'info_passe_trop_court' => 'Password too short.',
	'info_passe_trop_court_car_pluriel' => 'Your password must contain at least @nb@ characters.',
	'info_passes_identiques' => 'The two passwords are not identical.',
	'info_plus_cinq_car' => 'more than 5 characters',
	'info_plus_cinq_car_2' => '(More than 5 characters)',
	'info_plus_trois_car' => '(More than 3 characters)',
	'info_popularite' => 'popularity: @popularite@; visits: @visites@',
	'info_post_scriptum' => 'Postscript',
	'info_post_scriptum_2' => 'Postscript:',
	'info_pour' => 'for',
	'info_preview_texte' => 'It is possible to preview the site’s various editorial elements with at least the "submitted" status, as well as the "editing in progress" elements of which you are the author. for which status should this feature be available?',
	'info_procedez_par_etape' => 'please proceed step by step',
	'info_procedure_maj_version' => 'the upgrade procedure must be run to adapt
 the database to this new version of SPIP.',
	'info_proxy_ok' => 'Proxy test successful.',
	'info_ps' => 'P.S.',
	'info_publier' => 'publish',
	'info_publies' => 'Your articles published online',
	'info_question_accepter_visiteurs' => 'If your website’s templates allows accounts creation with no access to the back office, please enable the following option:',
	'info_question_inscription_nouveaux_redacteurs' => 'Do you wish to allow new registrations
 from the public site? If you agree with this, visitors will be able to  register
  using an automatic form, and then access the back office to
  write their own articles. <div class="notice">During the registration process, they usually receive an automatic email
  giving them their access code for the back office. Some
  hosting providers disable sending emails from their
  servers: in that case, automated registration is not
  possible.</div>',
	'info_qui_edite' => '@nom_auteur_modif@ worked on the contents @date_diff@ minutes ago',
	'info_racine_site' => 'Site root',
	'info_recharger_page' => 'Please wait a few moments, then reload this page.',
	'info_recherche_auteur_zero' => 'No results for "@cherche_auteur@".',
	'info_recommencer' => 'Please try again.',
	'info_redacteur_1' => 'Editor',
	'info_redacteur_2' => 'with access to the admin area (<i>recommended</i>)',
	'info_redacteurs' => 'Editors',
	'info_redaction_en_cours' => 'EDITING IN PROGRESS',
	'info_redirection' => 'Redirection',
	'info_redirection_activee' => 'Redirection is enabled.',
	'info_redirection_boucle' => 'You are trying to redirect the article toward itself. ',
	'info_redirection_desactivee' => 'Redirection is deleted.',
	'info_refuses' => 'Your rejected articles ',
	'info_reglage_ldap' => 'Options: <b>Adjusting LDAP import</b>',
	'info_renvoi_article' => '<b>Redirection.</b> This article redirects to:',
	'info_reserve_admin' => 'Only admins can modify this address.',
	'info_restreindre_rubrique' => 'Restrict management to section:',
	'info_resultat_recherche' => 'Search results:',
	'info_rubriques' => 'Sections',
	'info_rubriques_02' => 'sections',
	'info_rubriques_trouvees' => 'Sections found',
	'info_sans_titre' => 'Untitled',
	'info_selection_chemin_acces' => '<b>Select</b> the access path in the directory:',
	'info_signatures' => 'signatures',
	'info_site' => 'Site',
	'info_site_2' => 'site:',
	'info_site_min' => 'site',
	'info_site_reference_2' => 'Referenced site',
	'info_site_web' => 'Web site:',
	'info_sites' => 'sites',
	'info_sites_lies_mot' => 'Referenced sites with this keyword',
	'info_sites_proxy' => 'Using a proxy',
	'info_sites_trouves' => 'Sites found',
	'info_sous_titre' => 'Subtitle:',
	'info_statut' => 'Status',
	'info_statut_administrateur' => 'Admin',
	'info_statut_auteur' => 'This author’s status:',
	'info_statut_auteur_2' => 'I am',
	'info_statut_auteur_a_confirmer' => 'Registration to be confirmed',
	'info_statut_auteur_autre' => 'Other status:',
	'info_statut_redacteur' => 'Editor',
	'info_statut_utilisateurs_1' => 'Default status for imported accounts',
	'info_statut_utilisateurs_2' => 'Choose the status to be attributed to persons present in the LDAP directory when they connect for the first time. You can modify this value for each person later on.',
	'info_suivi_activite' => 'Follow editorial activity',
	'info_surtitre' => 'Top title:',
	'info_syndication_integrale_1' => 'Your site provides syndication files (see "<a href="@url@">@titre@</a>").',
	'info_syndication_integrale_2' => 'Do you wish to send whole articles or only a summary of a few hundred characters?',
	'info_table_prefix' => 'It is possible to change the prefix of the names of the database tables. (you need to do this if you are installing several sites in the same database). The prefix must be written in unaccented, lower-case letters without any spaces.',
	'info_taille_maximale_images' => 'SPIP will test for the maximum image size (in millions of pixels) which it can process.<br /> Images bigger than this will not be reduced.',
	'info_taille_maximale_vignette' => 'Maximum size for vignettes generated by the system:',
	'info_terminer_installation' => 'You can now finish the standard installation process.',
	'info_texte' => 'Text',
	'info_texte_explicatif' => 'Explanation',
	'info_texte_long' => '(The text is long: it will appear in several parts which will be reassembled after validation.)',
	'info_texte_message' => 'Text of your message:',
	'info_texte_message_02' => 'Message text',
	'info_titre' => 'Title:',
	'info_total' => 'total:',
	'info_tous_articles_en_redaction' => 'All articles in progress',
	'info_tous_articles_presents' => 'All articles published in this section',
	'info_tous_articles_refuses' => 'All refused articles',
	'info_tous_les' => 'every:',
	'info_tout_site' => 'The entire site',
	'info_tout_site2' => 'The article has not been translated into this language.',
	'info_tout_site3' => 'The article has been translated into this language, but changes have since been made to the reference article. The translation needs updating.',
	'info_tout_site4' => 'The article has been translated into this language, and the translation is up-to-date.',
	'info_tout_site5' => 'Original article.',
	'info_tout_site6' => '<b>Warning:</b> only original articles are displayed.
Translations are linked to the original,
and their status is colour-coded:',
	'info_traductions' => 'Translations',
	'info_travail_colaboratif' => 'Collaborative work on articles',
	'info_un_article' => 'an article,',
	'info_un_site' => 'a site,',
	'info_une_rubrique' => 'a section,',
	'info_une_rubrique_02' => '1 section',
	'info_url' => 'URL:',
	'info_url_proxy' => 'Proxy URL',
	'info_url_proxy_pas_conforme' => 'Proxy’s URL not valid.',
	'info_url_site_pas_conforme' => 'the website URL is invalid.',
	'info_url_test_proxy' => 'Test URL',
	'info_urlref' => 'Hyperlink:',
	'info_utilisation_spip' => 'SPIP is now ready for use',
	'info_version_base_plus_recente' => 'SPIP version in the database is more recent than the one you are using. This operation is not supported,please update your installation.',
	'info_visites_par_mois' => 'Monthly display:',
	'info_visiteur_1' => 'Visitor',
	'info_visiteur_2' => 'to the public site',
	'info_visiteurs' => 'Visitors',
	'info_visiteurs_02' => 'Public site visitors',
	'info_webmestre_forces' => 'The web-masters and web-mistresses are currently defined in <tt>@file_options@</tt>.',
	'install_adresse_base_hebergeur' => 'Database address attributed by the hosting provider',
	'install_connect_ok' => 'The new database has been declared using the server name @connect@.',
	'install_echec_annonce' => 'This installation will probably fail, or damage your site.',
	'install_extension_mbstring' => 'SPIP does not work with:',
	'install_extension_php_obligatoire' => 'SPIP requires the php extension:',
	'install_login_base_hebergeur' => 'Login attributed by the service provider',
	'install_nom_base_hebergeur' => 'Database name attributed by the service provider:',
	'install_pas_table' => 'The database has no tables',
	'install_pass_base_hebergeur' => 'Password attributed by your hosting service ',
	'install_php_extension' => 'The following extensions are missing : @extensions@',
	'install_php_version' => 'This version of PHP @version@ is too old (minimum = @minimum@)',
	'install_php_version_max' => 'PHP version @version@ too recent (maximum = @maximum@)',
	'install_select_langue' => 'Select a language, then click on "next" to start installation.',
	'install_select_type_db' => 'Indicate the type of database:',
	'install_select_type_mysql' => 'MySQL',
	'install_select_type_pg' => 'PostgreSQL',
	'install_select_type_sqlite2' => 'SQLite 2',
	'install_select_type_sqlite3' => 'SQLite 3',
	'install_serveur_hebergeur' => 'Database server attributed by the hosting provider',
	'install_table_prefix_hebergeur' => 'Table prefix attributed by your hosting provider:',
	'install_tables_base' => 'Tables in the database',
	'install_types_db_connus' => 'SPIP can use <b>MySQL</b> (the most common) and <b>SQLite</b>.',
	'install_types_db_connus_avertissement' => 'The support of <b>PostgreSQL</b is actually proposed as experimental',
	'instituer_erreur_statut_a_change' => 'The status has already been modified',
	'instituer_erreur_statut_a_definir' => 'Select a new status',
	'instituer_erreur_statut_non_autorise' => 'You cannot select this status',
	'intem_redacteur' => 'editor',
	'intitule_licence' => 'Licence',
	'item_accepter_inscriptions' => 'Allow registration',
	'item_activer_messages_avertissement' => 'Activate warning messages',
	'item_administrateur_2' => 'admin',
	'item_afficher_calendrier' => 'Display in calendar',
	'item_autoriser_syndication_integrale' => 'Include entire articles in syndication feeds',
	'item_choix_administrateurs' => 'admins',
	'item_choix_generation_miniature' => 'Generate thumbnails automatically.',
	'item_choix_non_generation_miniature' => 'Do not generate thumbnails.',
	'item_choix_redacteurs' => 'editors',
	'item_choix_visiteurs' => 'visitors to the public site',
	'item_creer_fichiers_authent' => 'Create .htpasswd files',
	'item_login' => 'Login',
	'item_messagerie_agenda' => 'Activate messaging system and calendars',
	'item_mots_cles_association_articles' => 'articles',
	'item_mots_cles_association_rubriques' => 'sections',
	'item_mots_cles_association_sites' => 'referenced or syndicated sites.',
	'item_non' => 'No',
	'item_non_accepter_inscriptions' => 'Disable registration',
	'item_non_activer_messages_avertissement' => 'No warning messages',
	'item_non_afficher_calendrier' => 'Do not show in calendar',
	'item_non_autoriser_syndication_integrale' => 'Only send a summary',
	'item_non_creer_fichiers_authent' => 'Do not create these files',
	'item_non_messagerie_agenda' => 'Disable the messaging system and calendars',
	'item_non_publier_articles' => 'Do not publish articles before their specified publication date.',
	'item_nouvel_auteur' => 'New author',
	'item_nouvelle_rubrique' => 'New section',
	'item_oui' => 'Yes',
	'item_publier_articles' => 'Publish articles, irrespective of publication date.',
	'item_reponse_article' => 'Reply to the article',
	'item_visiteur' => 'visitor',

	// J
	'jour_non_connu_nc' => 'unknown',

	// L
	'label_bando_outils' => 'Toolbar',
	'label_bando_outils_afficher' => 'Show the tools',
	'label_bando_outils_masquer' => 'Hide the tools',
	'label_choisir_timezone' => 'Time zone of the site',
	'label_choix_langue' => 'Choose your language',
	'label_langue' => 'Language',
	'label_nom_fichier_connect' => 'Indicate the name for this server',
	'label_slogan_site' => 'Website slogan',
	'label_taille_ecran' => 'Screen width',
	'label_texte_et_icones_navigation' => 'Navigation menu',
	'label_texte_et_icones_page' => 'Page display',
	'ldap_correspondance' => 'inherit field @champ@',
	'ldap_correspondance_1' => 'Inherit LDAP fields',
	'ldap_correspondance_2' => 'For each of these SPIP fields, enter the name of the corresponding LDAP field. Leave blank if you don’t want it filled, separate with spaces or commas to try several LDAP fields.',
	'lien_ajouter_auteur' => 'Add this author',
	'lien_ajouter_une_rubrique' => 'Add this section',
	'lien_email' => 'email',
	'lien_nom_site' => 'SITE NAME:',
	'lien_rapide_contenu' => 'Go to the content',
	'lien_rapide_navigation' => 'Go to the navigation',
	'lien_rapide_recherche' => 'Go to the search',
	'lien_retirer_auteur' => 'Remove author',
	'lien_retirer_rubrique' => 'Remove the section',
	'lien_retirer_tous_auteurs' => 'Remove all authors',
	'lien_retirer_toutes_rubriques' => 'Remove all sections',
	'lien_site' => 'site',
	'lien_tout_decocher' => 'Uncheck all',
	'lien_tout_deplier' => 'Expand all',
	'lien_tout_replier' => 'Collapse all',
	'lien_tout_supprimer' => 'Delete all',
	'lien_trier_nom' => 'Sort by name',
	'lien_trier_nombre_articles' => 'Sort by total articles',
	'lien_trier_statut' => 'Sort by status',
	'lien_voir_en_ligne' => 'VIEW ONLINE:',
	'logo_article' => 'Article’s logo',
	'logo_auteur' => 'Author’s logo',
	'logo_rubrique' => 'Section’s logo',
	'logo_site' => 'Website’s logo',
	'logo_standard_rubrique' => 'Default sections’ logo',
	'logo_survol' => 'Mouseover logo',

	// M
	'menu_aide_installation_choix_base' => 'Choosing your database',
	'module_fichier_langue' => 'Language file',
	'module_raccourci' => 'Shortcut',
	'module_texte_affiche' => 'Displayed text',
	'module_texte_explicatif' => 'You can insert thse shortcuts in your website templates. They will be automatically translated into any languages for which a language file exists.',
	'module_texte_traduction' => 'The language file « @module@ » is available in:',
	'mois_non_connu' => 'unknown',

	// N
	'nouvelle_version_spip' => 'SPIP upgrade @version@ is available',
	'nouvelle_version_spip_majeure' => 'A new SPIP version @version@ is available',

	// O
	'onglet_contenu' => 'Contents',
	'onglet_declarer_une_autre_base' => 'Declare another database',
	'onglet_discuter' => 'Discuss',
	'onglet_interactivite' => 'Interactivity',
	'onglet_proprietes' => 'Properties',
	'onglet_repartition_actuelle' => 'now',
	'onglet_sous_rubriques' => 'Subsections',

	// P
	'page_pas_proxy' => 'This page must not go through the proxy',
	'pas_de_proxy_pour' => 'If necessary, indicate to which machines or domains this proxy should not apply (for example: @exemple@)',
	'phpinfo' => 'PHP configuration',
	'plugin_charge_paquet' => 'Loading the archive file @name@',
	'plugin_charger' => 'Download',
	'plugin_erreur_charger' => 'error: @zip@ cannot be loaded',
	'plugin_erreur_droit1' => 'Cannot write to directory <code>@dest@</code>.',
	'plugin_erreur_droit2' => 'Please check write permissions for this directory (and create the directory if necessary). Alternatively, install the files by FTP.',
	'plugin_erreur_zip' => 'pclzip failure: error @status@',
	'plugin_etat_developpement' => 'under development',
	'plugin_etat_experimental' => 'experimental',
	'plugin_etat_stable' => 'stable',
	'plugin_etat_test' => 'being tested',
	'plugin_impossible_activer' => 'Impossible to activate the plugin @plugin@',
	'plugin_info_automatique1' => 'If you wish to allow automatic plugin installation, please:',
	'plugin_info_automatique1_lib' => 'If you want to let this library to be installed automatically, please:',
	'plugin_info_automatique2' => 'Create a directory <code>@rep@</code> ;',
	'plugin_info_automatique3' => 'Check that the server has the proper permissions to write to this directory.',
	'plugin_info_automatique_creer' => 'to create at the root of the website.',
	'plugin_info_automatique_exemples' => 'examples:',
	'plugin_info_automatique_ftp' => 'You may install plugins by FTP in the  <tt>@rep@</tt> directory',
	'plugin_info_automatique_lib' => 'Some plugins need to be able to load files into the <code>lib/</code> directory. This directory should be created at the website root.',
	'plugin_info_automatique_liste' => 'Your plugin lists:',
	'plugin_info_automatique_liste_officielle' => 'official plugins',
	'plugin_info_automatique_liste_update' => 'Update lists',
	'plugin_info_automatique_ou' => 'or...',
	'plugin_info_automatique_select' => 'Select a plugin below: SPIP will load it and will install it in the <code>@rep@</code> directory. If the plugin already exists, it will be updated.',
	'plugin_info_credit' => 'Credits',
	'plugin_info_erreur_xml' => 'Incorrect declaration of the plugin',
	'plugin_info_install_ok' => 'Installation successful',
	'plugin_info_necessite' => 'Requires:',
	'plugin_info_non_compatible_spip' => 'This plugin is incompatible with this version of SPIP',
	'plugin_info_plugins_dist_1' => 'The following plugins are loaded and activated in the @plugins_dist@ directory.',
	'plugin_info_plugins_dist_2' => 'They cannot be disabled.',
	'plugin_info_telecharger' => 'load from @url@ and install to @rep@',
	'plugin_info_upgrade_ok' => 'Successful update',
	'plugin_librairies_installees' => 'Libraries installed',
	'plugin_necessite_extension_php' => 'Requires the PHP extension @plugin@ version @version@.',
	'plugin_necessite_extension_php_sans_version' => 'Requires the PHP extension @plugin@',
	'plugin_necessite_lib' => 'This plugin requires the library @lib@',
	'plugin_necessite_php' => 'Requires @plugin@ version @version@.',
	'plugin_necessite_plugin' => 'Version @version@ of the plugin @plugin@ is required.',
	'plugin_necessite_plugin_sans_version' => 'Requires the plugin @plugin@',
	'plugin_necessite_spip' => 'SPIP version @version@ or newer is required.',
	'plugin_source' => 'source: ',
	'plugin_titre_automatique' => 'Automatic installation',
	'plugin_titre_automatique_ajouter' => 'Add plugins',
	'plugin_titre_installation' => '@plugin@ plugin installation',
	'plugin_titre_modifier' => 'My plugins',
	'plugin_utilise_extension_php' => 'The version of the PHP extension @plugin@ must be @version@.',
	'plugin_utilise_php' => '@plugin@ version must be @version@.',
	'plugin_utilise_plugin' => 'The version of the plugin @plugin@ must be @version@.',
	'plugin_zip_active' => 'Continue in order to activate',
	'plugin_zip_adresse' => 'To load a zipped plugin file, or a list of plugins, enter the path below.',
	'plugin_zip_adresse_champ' => 'Path of the plugin or list ',
	'plugin_zip_content' => 'It contains the following files(@taille@),<br />ready to be installed in the <code>@rep@</code> directory',
	'plugin_zip_installe_finie' => 'The file @zip@ has been unpacked and installed.',
	'plugin_zip_installe_rep_finie' => 'The file @zip@ has been unpacked and installed in the @rep@ directory',
	'plugin_zip_installer' => 'You may now install it.',
	'plugin_zip_telecharge' => 'The file @zip@ has been loaded',
	'plugins_actif_aucun' => 'No plugins active.',
	'plugins_actif_un' => 'One plugin active',
	'plugins_actifs' => '@count@ active plugins.',
	'plugins_actifs_liste' => 'Enabled',
	'plugins_compte' => '@count@ plugins',
	'plugins_disponible_un' => 'One plugin available',
	'plugins_disponibles' => '@count@ plugins available.',
	'plugins_erreur' => 'Error in the plugins: @plugins@',
	'plugins_liste' => 'List of plugins',
	'plugins_liste_dist' => 'Locked plugins',
	'plugins_recents' => 'Recent plugins',
	'plugins_tous_liste' => 'All',
	'plugins_vue_hierarchie' => 'Hierarchy',
	'plugins_vue_liste' => 'List',
	'protocole_ldap' => 'Protocol version:',

	// Q
	'queue_args_fonction_label' => 'Arguments passed to the function @fonction@',
	'queue_args_voir' => 'Show arguments',
	'queue_executer_maintenant' => 'Run now',
	'queue_fonction_label' => 'Function',
	'queue_info_purger' => 'You can delete all pending tasks and reset the list with periodic tasks',
	'queue_liens_label' => 'links',
	'queue_nb_jobs_in_queue' => '@nb@ pending tasks',
	'queue_next_job_in_nb_sec' => 'Next task in @nb@ s',
	'queue_next_job_scheduled' => 'Next job',
	'queue_no_job_in_queue' => 'No pending tasks',
	'queue_one_job_in_queue' => '1 pending task',
	'queue_priorite_tache' => 'priority',
	'queue_purger_queue' => 'Reset the tasks queue',
	'queue_statut_en_cours' => 'In progress',
	'queue_titre' => 'Background tasks',

	// R
	'repertoire_plugins' => 'Directory:',
	'required' => '(Required)',

	// S
	'sans_heure' => 'time not specified',
	'statut_admin_restreint' => 'restricted admin',
	'statut_webmestre' => 'webmaster',

	// T
	'tache_cron_asap' => 'CRON task @function@ (ASAP)',
	'tache_cron_secondes' => 'CRON task @function@ (every @nb@ s)',
	'taille_cache_image' => 'The images calculated automatically by SPIP (thumbnails, titles transformed into graphics, mathematical formulae in TeX format, etc.) take up a total of @taille@ in the @dir@ directory.',
	'taille_cache_moins_de' => 'The cache size is less than @octets@.',
	'taille_cache_octets' => 'The size of the cache is currently around @octets@.',
	'taille_cache_vide' => 'The cache is empty.',
	'taille_repertoire_cache' => 'Current cache size ',
	'text_article_propose_publication' => 'Article submitted for publication.',
	'texte_acces_ldap_anonyme_1' => 'Some LDAP servers do not allow anonymous access. In this case you must indicate an initial access identifier for future directory searches. However, in most cases the following fields can be left empty.',
	'texte_admin_effacer_01' => 'This command deletes <i>the entire</i> content of the database,
including <i>all</i> the accesses to the back office. After using it, you must
reinstall SPIP, to re-create a new database and a new admin access.',
	'texte_adresse_annuaire_1' => '(If your directory is installed on the same machine as your website, it is probably «localhost».)',
	'texte_ajout_auteur' => 'The following author was added to the article:',
	'texte_annuaire_ldap_1' => 'If you have access to a LDAP directory server, you can use it to import accounts automatically into SPIP.',
	'texte_article_statut' => 'Article status:',
	'texte_article_virtuel' => 'Virtual article',
	'texte_article_virtuel_reference' => '<b>Virtual article:</b> an article on your SPIP website which redirects to another URL. To remove redirection, delete the URL.',
	'texte_aucun_resultat_auteur' => 'No results for "@cherche_auteur@".',
	'texte_auteur_messagerie' => 'The back office shows connected persons in real time, which allows you to exchange messages directly . You can opt not to appear in this list (you are then "invisible" to others).',
	'texte_auteurs' => 'THE AUTHORS',
	'texte_choix_base_1' => 'Select your database:',
	'texte_choix_base_2' => 'The SQL server contains several databases.',
	'texte_choix_base_3' => '<b>Select</b> below the one attributed by your hosting provider:',
	'texte_choix_table_prefix' => 'Prefix for tables:',
	'texte_compte_element' => '@count@ element',
	'texte_compte_elements' => '@count@ elements',
	'texte_conflit_edition_correction' => 'Please compare differences between the two versions. You can also copy your changes and start over.',
	'texte_connexion_mysql' => 'Consult the information provided by your hosting service. It should contain the connection codes for the SQL server.',
	'texte_contenu_article' => '(Brief description of the article.)',
	'texte_contenu_articles' => 'Depending on the layout chosen for your site, you can decide
  that some article options are not to be used.
  Use the following list to choose which options should be available.',
	'texte_crash_base' => 'If your database
   crashed, you can try to repair it
   automatically.',
	'texte_creer_rubrique' => 'Before writing any articles,<br /> you must create a section.',
	'texte_date_creation_article' => 'ARTICLE CREATION DATE:',
	'texte_date_creation_objet' => 'Creation date:', # on ajoute le ":"
	'texte_date_publication_anterieure' => 'Date first published:',
	'texte_date_publication_anterieure_nonaffichee' => 'Hide previous publication date.',
	'texte_date_publication_article' => 'PUBLISHED ON:',
	'texte_date_publication_objet' => 'Published on:',
	'texte_definir_comme_traduction_rubrique' => 'This section is a translation of section number:',
	'texte_descriptif_rapide' => 'Brief description',
	'texte_effacer_base' => 'Delete the SPIP database',
	'texte_effacer_statistiques' => 'Delete the statistics',
	'texte_en_cours_validation' => 'The following articles and news have been submitted for evaluation.',
	'texte_enrichir_mise_a_jour' => 'You can enrich the layout of your text by using "typographical shortcuts".',
	'texte_fichier_authent' => '<b>Should SPIP create the special files <tt>.htpasswd</tt>
  and <tt>.htpasswd-admin</tt> in the directory @dossier@?</b>
<p>These files can be used to restrict access to connected persons to other parts of your site (for instance, external statistical programme).</p><p>If you have no need of such files, you can keep this option with its default value (no file creation).</p>',
	'texte_informations_personnelles_1' => 'The system will now  create your personal account for this site.',
	'texte_informations_personnelles_2' => '(Note: if it is a reinstallation, if your former access is still working, you can',
	'texte_introductif_article' => '(Introductory text for the article.)',
	'texte_jeu_caractere' => 'We advise using the universal alphabet (<tt>utf-8</tt>) on your site. This will make it possible to display text in any language. All modern browsers are fully comptabile with this character set.',
	'texte_jeu_caractere_3' => 'Your site currently uses this character set:',
	'texte_jeu_caractere_4' => 'If that does not correspond to your current data (this may occur after restoring your database from a backup), or if <em>you are setting up this site</em> and wish to use a different character set, please indicate the character set here:',
	'texte_login_ldap_1' => '(Keep empty for anonymous access or enter complete path, for instance «<tt>uid=smith, ou=users, dc=my-domain, dc=com</tt>».)',
	'texte_login_precaution' => 'Warning! This is the login which you are currently using.
 Use this form with caution...',
	'texte_messagerie_agenda' => 'This messaging system allows the exchange of messages in the back office. It is linked to a calendar.',
	'texte_mise_a_niveau_base_1' => 'You have just updated SPIP files.
 Now you must upgrade the site
 database.',
	'texte_modifier_article' => 'Edit this article:',
	'texte_multilinguisme' => 'If you want to manage objects in several languages​​, with complex navigation, you can add a language selection menu to these objects, depending on the organization of your site.',
	'texte_multilinguisme_trad' => 'You can also enable a system for managing links between the various translations of certain objects.',
	'texte_non_compresse' => '<i>uncompressed</i> (your server does not support this feature)',
	'texte_nouvelle_version_spip_1' => 'You have just installed a new version of SPIP.',
	'texte_nouvelle_version_spip_2' => 'This new version requires a more thorough update than usual. If you are the webmaster of this site, please delete the file @connect@ and restart installation in order to update your database connection parameters. <p>(PS.: if you have forgotten your connection parameters, take a look at the file @connect@ before deleting it!)</p>',
	'texte_operation_echec' => 'Go back to the previous page, select another database or create a new one. Verify the information provided by your hosting service.',
	'texte_plus_trois_car' => 'more than 3 characters',
	'texte_plusieurs_articles' => 'Several authors were found for "@cherche_auteur@":',
	'texte_port_annuaire' => '(Default value is generally suitable.)',
	'texte_presente_plugin' => 'This page shows the plugins available on this site. Activate the plugins you require by ticking the corresponding box.',
	'texte_proposer_publication' => 'When your article is finished,<br /> you can submit it for publication.',
	'texte_proxy' => 'In some cases (e.g. intranet, protected network), it is necessary to use an <i>HTTP proxy</i> to reach external sites (SPIP documentation, syndicated sites, etc.). If this is the case, enter its address in the form @proxy_en_cours@. In most cases you can leave this box empty.',
	'texte_publication_articles_post_dates' => 'Which behaviour should SPIP adopt for articles whose
  publication date has been set in
  the future?',
	'texte_rappel_selection_champs' => '[Remember to select this field correctly.]',
	'texte_recalcul_page' => 'If you want
to re-process a single page, it is easier to view that page from the public site and click "Re-process this page".',
	'texte_recuperer_base' => 'Repair the database',
	'texte_reference_mais_redirige' => 'article referenced in your SPIP site, but redirected to another URL.',
	'texte_requetes_echouent' => '<b>When some SQL queries fail
  systematically, without apparent reason, it is possible
  that the database itself
  is the culprit.</b><p>
  The SQL server has a feature for repairing tables
  which have been accidentally
 corrupted. Here, you can attempt to execute this repair; in
  the event of failure, you should keep a copy of the display, which might contain
  clues as to where the problem lies.</p><p>
  If the problem persists, contact your 
  service provider.</p>',
	'texte_selection_langue_principale' => 'You can choose the website’s "primary language". This does not mean that you can only write articles in that language, but it will be used to determine

<ul><li> the default date/time format on the public website,</li>
<li> the nature of the typographical engine which will be used by SPIP for rendering text,</li>
<li> the language in use in public website’s forms,</li>
<li> the default language in use in the admin area.</li></ul>',
	'texte_sous_titre' => 'Subtitle',
	'texte_statistiques_visites' => '(dark bars = Sunday, dark curve: average visits)',
	'texte_statut_attente_validation' => 'awaiting validation',
	'texte_statut_publies' => 'published online',
	'texte_statut_refuses' => 'rejected',
	'texte_suppression_fichiers' => 'Use this command to purge all the files
in the SPIP cache. This will force recalculation of every page on the site, useful after
significant modifications to the site’s graphics or structure.',
	'texte_sur_titre' => 'Lead-in title',
	'texte_table_ok' => ': this table is OK.',
	'texte_tentative_recuperation' => 'Attempting to repair',
	'texte_tenter_reparation' => 'Attempt to repair the database',
	'texte_test_proxy' => 'To test this proxy, enter the address of a website
    for verification.',
	'texte_titre_02' => 'Subject:',
	'texte_titre_obligatoire' => '<b>Title</b> [Required]',
	'texte_travail_article' => '@nom_auteur_modif@ edited this article @date_diff@ minutes ago',
	'texte_travail_collaboratif' => 'If several persons often work on the same article, the system can mark recently "opened" articles in order to avoid multiple simultaneous editing.
  This option is disabled by default to avoid displaying unnecessary warning
  messages.',
	'texte_vide' => 'empty',
	'texte_vider_cache' => 'Empty the cache',
	'titre_admin_bdd' => 'Database',
	'titre_admin_tech' => 'Technical maintenance',
	'titre_ajouter_un_auteur' => 'Add an author',
	'titre_ajouter_un_mot' => 'Add a keyword',
	'titre_cadre_afficher_article' => 'Show the articles:',
	'titre_cadre_afficher_traductions' => 'Display the translation status for these languages:',
	'titre_cadre_ajouter_auteur' => 'ADD AN AUTHOR:',
	'titre_cadre_interieur_rubrique' => 'In section',
	'titre_cadre_numero_auteur' => 'AUTHOR NUMBER',
	'titre_cadre_numero_objet' => '@objet@ NUMBER:',
	'titre_cadre_signature_obligatoire' => '<b>Signature</b> [Required]<br />',
	'titre_config_contenu_notifications' => 'Notifications',
	'titre_config_contenu_prive' => 'In the admin area',
	'titre_config_contenu_public' => 'On the public site',
	'titre_config_fonctions' => 'Site configuration',
	'titre_config_langage' => 'Configure the language',
	'titre_configuration' => 'Site configuration',
	'titre_configurer_preferences' => 'Configure your preferences',
	'titre_configurer_preferences_menus' => 'Settings of your menus preferences',
	'titre_conflit_edition' => 'Conflict while editing',
	'titre_connexion_ldap' => 'Options: <b>Your LDAP connection</b>',
	'titre_groupe_mots' => 'KEYWORD GROUP:',
	'titre_identite_site' => 'Site identity',
	'titre_langue_article' => 'Article language',
	'titre_langue_rubrique' => 'Section language',
	'titre_langue_trad_article' => 'ARTICLE LANGUAGE AND TRANSLATIONS',
	'titre_les_articles' => 'ARTICLES',
	'titre_messagerie_agenda' => 'Messaging system and calendar',
	'titre_naviguer_dans_le_site' => 'Browse the site...',
	'titre_nouvelle_rubrique' => 'New section',
	'titre_numero_rubrique' => 'SECTION NUMBER:',
	'titre_page_articles_edit' => 'Modify: @titre@',
	'titre_page_articles_page' => 'Articles',
	'titre_page_articles_tous' => 'The entire site',
	'titre_page_calendrier' => 'Calendar @nom_mois@ @annee@',
	'titre_page_config_contenu' => 'Site configuration',
	'titre_page_delete_all' => 'total and irreversible deletion',
	'titre_page_recherche' => 'Search results @recherche@',
	'titre_page_statistiques_referers' => 'Statistics (incoming links)',
	'titre_page_upgrade' => 'SPIP upgrade',
	'titre_preference_menus_favoris' => 'Favourites menu',
	'titre_publication_articles_post_dates' => 'Publication of post dated articles',
	'titre_reparation' => 'Repair',
	'titre_suivi_petition' => 'Petitions follow-up',
	'tls_ldap' => 'Transport Layer Security :',
	'trad_article_traduction' => 'All the versions of this article:',
	'trad_delier' => 'Stop linking to these translations',
	'trad_lier' => 'This article is a translation of article number:',
	'trad_new' => 'Write a new translation',

	// U
	'utf8_convert_erreur_orig' => 'Error: the character set @charset@ is not supported.',

	// V
	'version' => 'Version:',
];
